pub struct Padding2D {
pub top: usize,
pub bottom: usize,
pub left: usize,
pub right: usize,
}Expand description
Represents 2D padding with top, bottom, left, and right values (in pixels).
Fields
top: usizeAmount of padding to add on the top side.
bottom: usizeAmount of padding to add on the bottom side.
left: usizeAmount of padding to add on the left side.
right: usizeAmount of padding to add on the right side.
Implementations
Sourceimpl Padding2D
impl Padding2D
Sourcepub fn validate_size(&self, old_size: ImageSize, new_size: ImageSize) -> bool
pub fn validate_size(&self, old_size: ImageSize, new_size: ImageSize) -> bool
Validates that a new image size correctly matches the expected dimensions after applying this padding to an existing image.
Arguments
old_size: The original image size before padding.new_size: The resulting image size after padding.
Returns
trueif thenew_sizewidth and height are equal toold_size.width + left + rightandold_size.height + top + bottom, respectively.falseotherwise.
Example
use kornia_image::ImageSize;
use kornia_imgproc::padding::Padding2D;
let padding = Padding2D { top: 1, bottom: 1, left: 2, right: 2 };
let old_size = ImageSize { width: 4, height: 4 };
let new_size = ImageSize { width: 8, height: 6 };
assert!(padding.validate_size(old_size, new_size));Auto Trait Implementations
impl Freeze for Padding2D
impl RefUnwindSafe for Padding2D
impl Send for Padding2D
impl Sync for Padding2D
impl Unpin for Padding2D
impl UnsafeUnpin for Padding2D
impl UnwindSafe for Padding2D